psychopy_ext.models.HMAX.get_gaussians_matlab — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.models.HMAX.get_gaussians_matlab

`HMAX.` `get_gaussians_matlab`(filter_sizes_all, n_ori=4, sigDivisor=4.0)

  Generates 2D difference of Gaussians (DoG) filters. This is the original version of DoG filters used in HMAX. It was written in a very cumbersome way and thus I replaced it by the gaussian_filters function. If you want to produce identical numerical values of the filters, you should use this function. Otherwise, gaussian_filters does the job just as well, but much nicer.

  Parameters
    filter_sizes_all: list (depth 2))
      A nested list (grouped by filter bands) of integer filter sizes
    n_ori: int
      A number of filter orientations (default: 4) Orientations are spaced by np.pi/n_ori
    sigDivisor: float
      A parameter to adjust DoG filter frequency (default: 4.)
  Returns
    gaussians: list (depth 2)
      A nested list of filters of all orientations